# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-12-12 14:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0004_auto_20191212_1453'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='email',
            field=models.CharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='user',
            name='last_name',
            field=models.CharField(max_length=255),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-11-28 15:03
from __future__ import unicode_literals

from django.db import migrations, models
import djangoldp.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CodeFragment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('title', models.CharField(max_length=255)),
                ('body', models.TextField()),
                ('head', models.TextField(blank=True)),
                ('description', models.TextField(blank=True)),
                ('order', models.PositiveIntegerField(unique=True)),
            ],
            options={
                'ordering': ['order'],
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-12-12 14:53
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0003_users'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Users',
            new_name='User',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-12-18 10:33
from __future__ import unicode_literals

from django.db import migrations

def combine_names(apps, schema_editor):
    CodeFragment = apps.get_model('djangoldp_editor', 'CodeFragment')
    HelloWorld = apps.get_model('djangoldp_editor', 'HelloWorld')
    User = apps.get_model('djangoldp_editor', 'User')


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0006_auto_20191212_1510'),
    ]

    operations = [
         migrations.RunPython(combine_names),
    ]



from django.db import models
from djangoldp.models import Model

class CodeFragment(Model):
    title = models.CharField(max_length=255)
    body = models.TextField()
    head = models.TextField(blank=True)
    description = models.TextField(blank=True)
    order = models.PositiveIntegerField(unique=True)
    class Meta:
        ordering = ['order']

    def __str__(self):
        return self.title

class HelloWorld(Model):
    helloword = models.CharField(max_length=255)

    def __str__(self):
        return self.helloword

class User(Model):
    first_name = models.CharField(max_length=255)
    last_name = models.CharField(max_length=255)
    email = models.CharField(max_length=255)

    class Meta:
        anonymous_perms = ['add', 'change', 'delete', 'view']

    def __str__(self):
        return self.first_name


# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-12-12 15:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0005_auto_20191212_1454'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='user',
            options={},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.26 on 2019-12-12 14:53
from __future__ import unicode_literals

from django.db import migrations, models
import djangoldp.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_editor', '0002_helloworld'),
    ]

    operations = [
        migrations.CreateModel(
            name='Users',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('urlid', djangoldp.fields.LDPUrlField(blank=True, null=True, unique=True)),
                ('first_name', models.CharField(max_length=255)),
                ('last_name', models.TextField(max_length=255)),
                ('email', models.TextField(blank=True)),
            ],
            options={
                'abstract': False,
                'default_permissions': ('add', 'change', 'delete', 'view', 'control'),
            },
        ),
    ]



import factory
import hashlib
from .models import CodeFragment
from django.db.models.signals import post_save

@factory.django.mute_signals(post_save)
class EditorFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = CodeFragment

    # Please refer to Factory boy documentation
    # https://factoryboy.readthedocs.io
